Module: Hyrax::V2GraphIndexer

Defined in:
lib/hyrax/v2_graph_indexer.rb,
lib/hyrax/v2_graph_indexer/railtie.rb,
lib/hyrax/v2_graph_indexer/version.rb

Overview

The purpose of this module is to consolidate the decorations necessary to leverage the native SOLR graph searches. That native SOLR graph searches replaces the venerable and non-performant nested indexing.

These decorations are inspired from the following pull requests:

This lib file is intended to stand in the place of minting a 2.9.x release (or 2.10.0 release). In constructing these changes, I have opted not to backport the configuration. Meaning, if you include this lib file, you are stating that you will use the native SOLR graph searches. This simplifies some of the logic; most notably avoiding the conditional include of the Hyrax::CollectionNesting based on a configuration. Instead we have a module that shadows the methods introduced in the Hyrax::CollectionNesting.

Defined Under Namespace

Modules: CollectionNestingDecorator, NestCollectionFormDecorator, NestedCollectionPersistenceServiceDecorator, NestedCollectionQueryServiceDecorator, NestedCollectionsSearchBuilderDecorator Classes: Railtie

Constant Summary collapse

VERSION =
"0.5.0"